import React, { forwardRef, useRef } from 'react';
import mergeRefs from 'react-merge-refs';
import cn from 'classnames';
import { dom } from '@alfalab/core-components-shared/modern';
import { useFocus } from '@alfalab/hooks';
import { CheckIcon } from './icon.js';

const defaultColors = {"box":"checkbox__box_1pby7","checkedIcon":"checkbox__checkedIcon_1pby7","component":"checkbox__component_1pby7","disabled":"checkbox__disabled_1pby7","checked":"checkbox__checked_1pby7","indeterminate":"checkbox__indeterminate_1pby7","indeterminateLine":"checkbox__indeterminateLine_1pby7","label":"checkbox__label_1pby7","hint":"checkbox__hint_1pby7"};
require('./styles/default.css')

const styles = {"component":"checkbox__component_1azyd","start":"checkbox__start_1azyd","center":"checkbox__center_1azyd","addons":"checkbox__addons_1azyd","block":"checkbox__block_1azyd","box":"checkbox__box_1azyd","checkedIcon":"checkbox__checkedIcon_1azyd","size-20":"checkbox__size-20_1azyd","disabled":"checkbox__disabled_1azyd","focused":"checkbox__focused_1azyd","content":"checkbox__content_1azyd","label":"checkbox__label_1azyd","errorMessage":"checkbox__errorMessage_1azyd","hint":"checkbox__hint_1azyd","indeterminateLine":"checkbox__indeterminateLine_1azyd"};
require('./styles/index.css')

const invertedColors = {"box":"checkbox__box_iq9ck","checkedIcon":"checkbox__checkedIcon_iq9ck","component":"checkbox__component_iq9ck","disabled":"checkbox__disabled_iq9ck","checked":"checkbox__checked_iq9ck","indeterminate":"checkbox__indeterminate_iq9ck","indeterminateLine":"checkbox__indeterminateLine_iq9ck","label":"checkbox__label_iq9ck","hint":"checkbox__hint_iq9ck"};
require('./styles/inverted.css')

const colorStyles = {
    default: defaultColors,
    inverted: invertedColors,
};
const SIZE_TO_CLASSNAME_MAP = {
    s: 'size-20',
    m: 'size-24',
    20: 'size-20',
    24: 'size-24',
};
const Checkbox = forwardRef(({ checked, label, hint, size = 20, boxClassName, contentClassName, align = 'start', addons, block, onChange, className, name, disabled, inactive, dataTestId, indeterminate = false, hiddenInput = false, labelProps, error, inputRef, colors = 'default', ...restProps }, ref) => {
    const labelRef = useRef(null);
    const [focused] = useFocus(labelRef, 'keyboard');
    const handleChange = (event) => {
        if (onChange) {
            onChange(event, { checked: event.target.checked, name });
        }
    };
    const errorMessage = typeof error === 'boolean' ? '' : error;
    const colorStyle = colorStyles[colors];
    return (React.createElement("label", { ...labelProps, className: cn(styles.component, colorStyle.component, styles[SIZE_TO_CLASSNAME_MAP[size]], styles[align], className, labelProps?.className, {
            [styles.disabled]: disabled || inactive,
            [colorStyle.disabled]: disabled || inactive,
            [styles.checked]: checked,
            [colorStyle.checked]: checked,
            [styles.indeterminate]: indeterminate,
            [colorStyle.indeterminate]: indeterminate,
            [styles.focused]: focused,
            [styles.block]: block,
        }), ref: mergeRefs([labelRef, ref, labelProps?.ref]) },
        !hiddenInput && (React.createElement("input", { type: 'checkbox', onChange: handleChange, name: name, disabled: disabled || inactive, checked: checked, "data-test-id": dataTestId, ref: inputRef, ...restProps })),
        React.createElement("span", { className: cn(styles.box, colorStyle.box, boxClassName) },
            checked && (React.createElement(CheckIcon, { className: cn(styles.checkedIcon, colorStyle.checkedIcon) })),
            indeterminate && !checked && (React.createElement("span", { className: cn(styles.indeterminateLine, colorStyle.indeterminateLine) }))),
        (label || hint || errorMessage) && (React.createElement("span", { className: cn(styles.content, contentClassName) },
            label && (React.createElement("span", { className: cn(styles.label, colorStyle.label) }, label)),
            hint && !errorMessage && (React.createElement("span", { className: cn(styles.hint, colorStyle.hint) }, hint)),
            errorMessage && (React.createElement("span", { className: styles.errorMessage, role: 'alert' }, errorMessage)))),
        addons && (
        // eslint-disable-next-line jsx-a11y/click-events-have-key-events,jsx-a11y/no-static-element-interactions
        React.createElement("span", { className: styles.addons, onClick: dom.preventDefault }, addons))));
});
/**
 * Для отображения в сторибуке
 */
Checkbox.defaultProps = {
    indeterminate: false,
};
Checkbox.displayName = 'Checkbox';

export { Checkbox };
